@@ -1,7 +1,7 @@
 #!/usr/bin/env bash
 # Script to download/unpack and locally install the GNU Health demo database
 
-URL="http://health.gnu.org/downloads/postgres_dumps/gnuhealth-2.8.0-demo.sql.gz"
+URL="http://health.gnu.org/downloads/postgres_dumps/gnuhealth-3.0.1-demo-data.tar.gz"
 DB="gnuhealth_demo"
 
 if [[ $USER != "gnuhealth" ]]; then
@@ -26,19 +26,19 @@ trap cleanup SIGHUP SIGINT SIGTERM EXIT
 
 echo -n 'Downloading the demo database...'
 wget -q "$URL" -O demo_database.sql.gz
-echo 'Finished the download.'
+echo 'COMPLETE'
 
 echo -n 'Unpacking the database...'
 gunzip -q demo_database.sql.gz
-echo 'Finished unpacking.'
+echo 'COMPLETE'
 
 echo -n 'Initializing empty database...'
-psql -q -d template1 -c "create database $DB"
-echo 'Empty database initialized.'
+psql -q -d template1 -c "create database $DB encoding='unicode'"
+echo 'COMPLETE'
 
 echo -n 'Importing demo database...'
 psql -q "$DB" < demo_database.sql > /dev/null 2>&1
-echo 'Imported successfully.'
+echo 'COMPLETE'
 
 echo 'Use Tryton to access (with non-gnuhealth user!)...'
 echo "    Database: $DB"
